``tornado.wsgi`` --- Interoperability with other Python frameworks and servers
==============================================================================

.. automodule:: tornado.wsgi

   Running Tornado apps on WSGI servers
   ------------------------------------

   .. autoclass:: WSGIAdapter
      :members:

   .. autoclass:: WSGIApplication
      :members:

   Running WSGI apps on Tornado servers
   ------------------------------------
  
   .. autoclass:: WSGIContainer
      :members:
